import { getPayConfig } from '@/modules/pay-config.ts'
import axios from 'axios'
import WxPay from 'wechatpay-node-v3' // 支持使用require
const wechatApi = 'https://api.mch.weixin.qq.com/v3/pay/transactions/native'
const request = axios.create({
  timeout: 10000,
  headers: {
    'Content-Type': 'application/json',
    Accept: 'application/json'
  }
})

// tsx src/routes/pay/wechatpay/init.ts
export const initSdk = () => {
  const payConfig = getPayConfig()
  const wechat = payConfig.pay_platform.wechat

  const pay = new WxPay({
    appid: wechat.appid,
    mchid: wechat.mch_id,
    publicKey: Buffer.from(wechat.public_key), // 公钥
    privateKey: Buffer.from(wechat.private_key), // 秘钥
    key: wechat.api_v3_key, // 商户API密钥
  })
  const sign = (params: any, url = '/v3/pay/transactions/native') => {
    const nonce_str = Math.random().toString(36).substr(2, 15), // 随机字符串
      timestamp = parseInt(+new Date() / 1000 + '').toString() // 时间戳 秒
    // url = '/v3/pay/transactions/h5'

    // # 获取签名
    const signature = pay.getSignature('POST', nonce_str, timestamp, url, params) //# 如果是get 请求 则不需要params 参数拼接在url上 例如 /v3/pay/transactions/id/12177525012014?mchid=1230000109
    // # 获取头部authorization 参数
    const authorization = pay.getAuthorization(nonce_str, timestamp, signature)
    return {
      nonce_str,
      timestamp,
      authorization
    }
  }
  const createParams = (amount: number, orderId: string, opts?: any) => {
    return {
      appid: wechat.appid,
      mchid: wechat.mch_id,
      description: 'Image形象店-深圳腾大-QQ公仔',
      out_trade_no: orderId,
      notify_url: 'https://www.weixin.qq.com/wxpay/pay.php',
      ...opts,
      amount: {
        total: amount
      }
    }
  }
  const curl = async (amount: number, orderId: string, opts?: any) => {
    const params = createParams(amount, orderId, opts)
    const { authorization } = sign(params)
    // console.log('authorization', authorization)
    const result = await request.post(wechatApi, params, {
      headers: {
        Accept: 'application/json',
        'Content-Type': 'application/json',
        'User-Agent':
          'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/87.0.4280.88 Safari/537.36',
        Authorization: authorization
      }
    })
    return result.data
  }
  return {
    pay,
    createParams,
    sign,
    curl
  }
}

export const getPaymentQRCode = async (amount: number, orderId: string) => {
  try {
    const sdk = initSdk()
    // const result = await sdk.curl(amount, orderId)
    const result = await sdk.pay.transactions_native({
      description: 'Image形象店-深圳腾大-QQ公仔',
      out_trade_no: '12177525012014',
      notify_url: 'https://www.weixin.qq.com/wxpay/pay.php',
      amount: {
        total: 100
      }
    })
    console.log('GET QR Code URL:', result)
  } catch (error) {
    console.error('Error fetching payment QR code:', error)
    throw error
  }
}

